import { For, createSignal, createEffect, Show, onMount } from 'solid-js'
import ConversationSidebarItem from './listItem'
import { createStore } from "solid-js/store";
import '../css/list.css'
import { fetchData } from '../../../http/api'


export default () => {
    // dataItemLists.set([{id:'1'},{id:'2'},{id:'3'},{id:'4'},{id:'5'},{id:'6'}])
    const [list, setList] = createStore({
        data: [{ id: '1', Topping: false }, { id: '2', Topping: false }, { id: '3', Topping: false }, { id: '4', Topping: false }, { id: '5', Topping: false }, { id: '6', Topping: false }]
    })

    type errorObj={
        show:boolean,
        message:string
    }

    let [errorShow, setErrorShow] = createSignal({
        show: false,
        message: ''
    })

    const getList = () => {
        fetchData({}, function (data) {
            if (data.code === 200) {
                setList('data', () => [...data.data])
            }
        }, '/chat/api', 'GET');
    }

    //标题
    let dialogueName = ''

    //新建对话框
    const newlyAdded = () => {
        window.open(`${location.protocol}//${location.host}`)
    }

    //删除记录
    let deleteItem = { key: null, e: null }
    const handleDelete = (e: MouseEvent, key: string) => {
        let arr = JSON.parse(JSON.stringify(list)).data
        fetchData({
            uniqid: arr[key].uniqid
        }, function (data) {
            if (data.code === 200) {
                arr.splice(key, 1)
                setList('data', (list) => [...arr])
            }
        }, '/chat/delete', 'POST');

        e.stopPropagation()
    }

    //判断平台
    const isMobile = () => {
        let flag = navigator.userAgent.match(
            /(phone|pad|pod|iPhone|iPod|ios|iPad|Android|Mobile|BlackBerry|IEMobile|MQQBrowser|JUC|Fennec|wOSBrowser|BrowserNG|WebOS|Symbian|Windows Phone)/i
        );
        return flag;
    }
    //弹窗
    let [pop, setPop] = createSignal(false)
    let [popType, setPopType] = createSignal('open')

    const popShow = (type: string, e: any, key: number, name: string = '未命名对话') => {
        setPopType(type)
        if (type == 'delete') {
            deleteItem['key'] = key as any
            deleteItem['e'] = e
        }
        if (type === 'open') dialogueName = name
        setPop(!pop())
    }

    //确认按钮
    const determineBtn = () => {
        if (popType() === 'open') {
            sessionStorage.setItem('dialogueName', JSON.stringify({ name: dialogueName, switch: true }))
            if (isMobile()) {
                location.pathname = '/'
            } else {
                newlyAdded()
            }
        } else if (popType() === 'delete') {
            handleDelete(deleteItem['e'] as any, deleteItem['key'] as any)
        }
        setPop(false)
    }

    //显示错误提示
    const setErrorFun=(message:string)=>{
        setErrorShow({
            message,
            show:true
        })
    }

    //提示弹窗
    const ErrorState = () => (
        <div class='tps-error-box'>
            <div class="max-w-base h-full flex items-end flex-col justify-between gap-8 sm:(flex-row items-center) py-4 text-error text-sm" style="padding: 1rem;">
                <div class="flex-1 w-full">
                    <div class="fi gap-0.5 mb-1">
                        <span i-carbon-warning />
                        <span class="font-semibold">{errorShow().message}</span>
                    </div>
                </div>
                <div class="border border-error px-2 py-1 rounded-md hv-base hover:bg-white" onClick={() => { setErrorShow({ show: false, message: errorShow().message }) }} >
                    Dismiss
                </div>
            </div>
        </div>
    )

    onMount(() => {
        getList()
    })

    return (
        <div class="h-full flex flex-col bg-sidebar max-w-350 min-w-260">
            <Show when={pop()}>
                <div class='pop center-f'>
                    <div class='center-f text-box'>
                        <div>
                            <div class='pop-title'>
                                <Show when={popType() == 'open'}>
                                    是否创建新的窗口?
                                </Show>
                                <Show when={popType() == 'delete'}>
                                    是否删除分享记录?
                                </Show>
                            </div>
                            <div class='btn-box'>
                                <div class='btn center-f' onClick={determineBtn}>确认</div>
                                <div class='btn mg-l-80 center-f' onClick={() => setPop(false)}>取消</div>
                            </div>
                        </div>
                    </div>
                </div>
            </Show>
            <Show when={errorShow().show}>
                <ErrorState />
            </Show>
            <div class="flex-1 overflow-auto">
                <div class="px-2">
                    <For each={list.data}>
                        {(instance, i) => (
                            <ConversationSidebarItem popShow={popShow} setErrorFun={setErrorFun} instanceData={{ ...instance }} infoList={list.data} key={i as any} setList={setList} />
                        )}
                    </For>
                </div>
            </div>
        </div>
    )
}
